Talks & Tutorials
=================

.. raw:: html

   <iframe width="560"
           height="315"
           src="https://www.youtube.com/embed/nnndxbr_Xq4"
           style="margin: 0 auto 20px auto; display: block;"
           frameborder="0"
           allow="accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture"
           allowfullscreen></iframe>

Dask Tutorial
-------------

`Dask Tutorial <https://tutorial.dask.org>`__ provides an overview of Dask and is typically delivered in 3 hours.
See `Parallel and Distributed Computing in Python with Dask <https://www.youtube.com/watch?v=EybGGLbLipI>`__ for the
latest Dask Tutorial recording from SciPy 2020.

Dask YouTube channel
--------------------
You can find lots of videos about Dask on the `Dask YouTube channel <https://www.youtube.com/c/dask-dev>`__

.. contents:: :local:
